@@ -482,7 +482,8 @@ main (int argc, char *const *argv)
     }
   fwrite (TESTSTR, strlen (TESTSTR), 1, f);
   fclose (f);
-  oneone = NULL != strstr (argv[0], "11");
+  oneone = (NULL != strrchr (argv[0], (int) '/')) ?
+    (NULL != strstr (strrchr (argv[0], (int) '/'), "11")) : 0;
   if (0 != curl_global_init (CURL_GLOBAL_WIN32))
     return 2;
   errorCount += testInternalGet ();
